#!/usr/bin/perl
use strict;
use warnings 'FATAL' => 'all';

my $use_offsets = $ARGV[0] ? 0 : 1;

my %offsets = (
  '00' => [ 0, 0, 0 ],
  '01' => [ -12, 27, 0 ],
  '02' => [ -3, 29, 0 ],
  '03' => [ -18, 58, 0 ],
  '04' => [ -18, 87, 0 ],
  '05' => [ -18, 87, 0 ],
  '06' => [ -30, 88, 0 ],
  '07' => [ 10, 2, 0 ],
  '08' => [ 9, 4, 0 ],
  '09' => [ 10, 13, 0 ],
  '10' => [ -27, 17, 0 ],
  '11' => [ -12, 24, 0 ],
  '12' => [ 2, 31, 0 ],
  '14' => [ -6, 14, 0 ],
  );

our (@verts, %vlookup, @faces);
our $sec2meter = 2;

while (my $line = <STDIN>)
{
  chomp $line;
  my ($lev, $height, $type, @pts) = split(' ', $line);
  my ($xoff, $yoff, $zoff) = (0, 0, 0);
  
  if ($use_offsets)
  {
    next unless $offsets{$lev};
    ($xoff, $yoff, $zoff) = @{ $offsets{$lev} };
    $zoff += $height / $sec2meter;
  }
  
  if ($type eq 'floor')
  {
    AddFloor($xoff, $yoff, $zoff, @pts);
  }
  else
  {
    ExtrudePoly($xoff, $yoff, $zoff, @pts);
  }
}
PrintVertices();
PrintFaces();
exit;


sub Vertex
{
  my ($x, $y, $z) = @_;
  
  my $vref = sprintf("%.2f %.2f %.2f", $x * $sec2meter, -$y * $sec2meter, $z * $sec2meter);
  my $idx = $vlookup{$vref};
  unless ($idx)
  {
    push(@verts, "v $vref");
    $idx = scalar(@verts);
    $vlookup{$vref} = $idx;
  }
  return $idx;
}
sub PrintVertices
{
  print join("\n", @verts) . "\n\n";
}

sub Face
{
  my (@vs) = @_;
  push(@faces, join(' ', 'f', @vs));
}
sub PrintFaces
{
  print join("\n", @faces) . "\n\n";
}

sub Points2Lines
{
  my (@pts) = @_;
  
  my @lines = ();
  my $last = shift @pts;
  push(@pts, $last);
  while (scalar @pts)
  {
    my $next = shift @pts;
    push(@lines, [ $last, $next ]);
    $last = $next;
  }
  return @lines;
}

sub AddFloor
{
  my ($xoff, $yoff, $zoff, @pts) = @_;
  
  my @floor;
  for my $p (@pts)
  {
    my ($x, $y) = split(',', $p);
    push(@floor, Vertex($x + $xoff, $y - $yoff, $zoff));
  }
  Face(@floor);
}

sub ExtrudePoly
{
  my ($xoff, $yoff, $zoff, @pts) = @_;
  
  # we should already have floor: just add ceiling
  AddFloor($xoff, $yoff, $zoff + 1, @pts);
  
  # now walls
  for my $line (Points2Lines(@pts))
  {
    my ($p1, $p2) = @$line;
    my ($x1, $y1) = split(',', $p1);
    my ($x2, $y2) = split(',', $p2);
    my @wall = (
         Vertex($x2 + $xoff, $y2 - $yoff, $zoff),
         Vertex($x2 + $xoff, $y2 - $yoff, $zoff + 1),
         Vertex($x1 + $xoff, $y1 - $yoff, $zoff + 1),
         Vertex($x1 + $xoff, $y1 - $yoff, $zoff));
    Face(@wall);
    
  }
}
  
  

